@@ -80,13 +80,13 @@ recordTableIndividual <- function(inDir,
     }
   }
 
-  stopifnot(is.logical(removeDuplicateRecords))
-  stopifnot(is.logical(returnFileNamesMissingTags))
+  if(!is.logical(removeDuplicateRecords))     stop("'removeDuplicateRecords' must be logical (TRUE / FALSE)", call. = FALSE)
+  if(!is.logical(returnFileNamesMissingTags)) stop("'returnFileNamesMissingTags' must be logical (TRUE / FALSE)", call. = FALSE)
 
   metadata.tagname <- "HierarchicalSubject"    # for extracting metadata assigned in tagging software
 
   minDeltaTime <- as.integer(minDeltaTime)
-  stopifnot(is.integer(minDeltaTime))
+  if(!is.integer(minDeltaTime)) stop("'minDeltaTime' must be an integer", call. = FALSE)
 
   if(minDeltaTime != 0){
     if(removeDuplicateRecords == FALSE){
@@ -103,7 +103,7 @@ recordTableIndividual <- function(inDir,
     }
   }
 
-  stopifnot(is.logical(writecsv))
+  if(!is.logical(writecsv)) stop("writecsv must be logical")
 
   if(!is.character(inDir))  stop("inDir must be of class 'character'", call. = FALSE)
   if(length(inDir) != 1)    stop("inDir may only consist of 1 element only", call. = FALSE)
@@ -155,7 +155,9 @@ recordTableIndividual <- function(inDir,
   colnames.tmp <- c("Directory", "FileName", "DateTimeOriginal")
   if(hasArg(video)) colnames.tmp <- c(colnames.tmp, video$dateTimeTag)
   colnames.tmp <- c(colnames.tmp, "HierarchicalSubject")
-  if(hasArg(additionalMetadataTags)) colnames.tmp <- c(colnames.tmp, additionalMetadataTags)
+  if(hasArg(additionalMetadataTags)) colnames.tmp <- c(colnames.tmp, additionalMetadataTags [nchar(additionalMetadataTags) >= 2]) 
+  # only add as new column if entry of additionalMetadataTag has more than 2 characters (to allow users to specify exiftool commands, e.g. -L)
+  
   
   for(i in 1:length(dirs)){   # loop through station directories
 
@@ -183,9 +185,9 @@ recordTableIndividual <- function(inDir,
                                                                     digiKamTablesList = digiKam_data,    # output of accessDigiKamDatabase
                                                                     videoFormat = file_formats[!grepl(file_formats, pattern = "jpg")])
           # add HierarchialSubject for video files (match by filename, must be unique)
-          metadata.tmp <- addVideoHierachicalSubject (metadata.tmp = metadata.tmp,
-                                                      video = video,
-                                                      digiKamVideoMetadata = digiKamVideoMetadata)
+          metadata.tmp <- addVideoHierarchicalSubject (metadata.tmp = metadata.tmp,
+                                                       video = video,
+                                                       digiKamVideoMetadata = digiKamVideoMetadata)
         }
       }
       
